@@ -30,10 +30,8 @@
 #                                                                              #
 ################################################################################
 
-from __future__ import absolute_import
-import github.GithubObject
-
 import github.GitAuthor
+import github.GithubObject
 import github.GitTree
 
 
@@ -125,18 +123,26 @@ class GitCommit(github.GithubObject.CompletableGithubObject):
 
     def _useAttributes(self, attributes):
         if "author" in attributes:  # pragma no branch
-            self._author = self._makeClassAttribute(github.GitAuthor.GitAuthor, attributes["author"])
+            self._author = self._makeClassAttribute(
+                github.GitAuthor.GitAuthor, attributes["author"]
+            )
         if "committer" in attributes:  # pragma no branch
-            self._committer = self._makeClassAttribute(github.GitAuthor.GitAuthor, attributes["committer"])
+            self._committer = self._makeClassAttribute(
+                github.GitAuthor.GitAuthor, attributes["committer"]
+            )
         if "html_url" in attributes:  # pragma no branch
             self._html_url = self._makeStringAttribute(attributes["html_url"])
         if "message" in attributes:  # pragma no branch
             self._message = self._makeStringAttribute(attributes["message"])
         if "parents" in attributes:  # pragma no branch
-            self._parents = self._makeListOfClassesAttribute(GitCommit, attributes["parents"])
+            self._parents = self._makeListOfClassesAttribute(
+                GitCommit, attributes["parents"]
+            )
         if "sha" in attributes:  # pragma no branch
             self._sha = self._makeStringAttribute(attributes["sha"])
         if "tree" in attributes:  # pragma no branch
-            self._tree = self._makeClassAttribute(github.GitTree.GitTree, attributes["tree"])
+            self._tree = self._makeClassAttribute(
+                github.GitTree.GitTree, attributes["tree"]
+            )
         if "url" in attributes:  # pragma no branch
             self._url = self._makeStringAttribute(attributes["url"])
