@@ -121,12 +121,18 @@ class Notification(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck("PATCH", self.url,)
 
     def get_pull_request(self):
+        """
+        :type: :class:github.PullRequest.PullRequest
+        """
         headers, data = self._requester.requestJsonAndCheck("GET", self.subject.url)
         return github.PullRequest.PullRequest(
             self._requester, headers, data, completed=True
         )
 
     def get_issue(self):
+        """
+        :type: :class:github.Issue.Issue
+        """
         headers, data = self._requester.requestJsonAndCheck("GET", self.subject.url)
         return github.Issue.Issue(self._requester, headers, data, completed=True)
 
